SunPy instr
***********

The ``instr`` submodule contains instrument specific routines, generally this
submodule is focused on routines that process calibrated data.


.. automodapi:: sunpy.instr

.. automodapi:: sunpy.instr.aia

.. automodapi:: sunpy.instr.fermi

.. automodapi:: sunpy.instr.goes

.. automodapi:: sunpy.instr.iris

.. automodapi:: sunpy.instr.lyra

.. automodapi:: sunpy.instr.rhessi
